<?php
global $artha_options;

/**
 * Redux Theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Redux Theme
 */

if ( ! function_exists( 'artha_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function artha_setup() {
	/*
	 * Add Redux Framework
	 */
	require get_template_directory() . '/admin/admin-init.php';

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Redux Theme, use a find and replace
		 * to change 'artha-interactive' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'artha-interactive', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_image_size( 'artha-thumbnail', 532, 725 , true); //cropped center
		add_image_size( 'artha-icon', 65, 65 , true); //cropped center

		// This theme uses wp_nav_menu() in Cone location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'artha-interactive' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'artha_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

        add_theme_support( 'woocommerce' );
	}
endif;
add_action( 'after_setup_theme', 'artha_setup' );
require_once get_template_directory() . '/visual/shortcodes.php';
require_once get_template_directory() . '/visual/vc_shortcode.php';
/**
 * Widgets init
 * 
 * @return Void
 */
function finance_custom_css_classes_for_vc_row_and_vc_column($class_string, $tag) {
    if($tag=='vc_row' || $tag=='vc_row_inner') {
        $class_string = str_replace('vc_row-fluid', '', $class_string);
    }
    if($tag=='vc_column' || $tag=='vc_column_inner') {
    $class_string = preg_replace('/vc_col-sm-12/', 'col-md-12', $class_string);
    $class_string = preg_replace('/vc_col-sm-6/', 'col-md-6', $class_string);
    $class_string = preg_replace('/vc_col-sm-4/', 'col-md-4', $class_string);
    $class_string = preg_replace('/vc_col-sm-3/', 'col-md-3', $class_string);
    $class_string = preg_replace('/vc_col-sm-5/', 'col-md-5', $class_string);
    $class_string = preg_replace('/vc_col-sm-7/', 'col-md-7', $class_string);
    $class_string = preg_replace('/vc_col-sm-8/', 'col-md-8', $class_string);
    $class_string = preg_replace('/vc_col-sm-9/', 'col-md-9', $class_string);
    $class_string = preg_replace('/vc_col-sm-10/', 'col-md-10', $class_string);
    $class_string = preg_replace('/vc_col-sm-11/', 'col-md-11', $class_string);
    $class_string = preg_replace('/vc_col-sm-1/', 'col-md-1', $class_string);
    $class_string = preg_replace('/vc_col-sm-2/', 'col-md-2', $class_string);
    }
    return $class_string;
}
// Filter to Replace default css class for vc_row shortcode and vc_column
add_filter('vc_shortcodes_css_class', 'finance_custom_css_classes_for_vc_row_and_vc_column', 10, 2); 
// Add new Param in Row
if(function_exists('vc_add_param')){

vc_add_param('vc_row',array(
                             'type' => 'dropdown',
                             'heading' => esc_html__( 'Chosen type row', 'finance' ),
                             'param_name' => 'type_row',
                             'value' => array(
                                esc_html__( 'None', 'finance' ) => '',
                                esc_html__( 'Intro', 'finance' ) => 'intro',
                                esc_html__( 'About Us 1', 'finance' ) => 'about_us_1',
                                esc_html__( 'About Us 2', 'finance' ) => 'about_us_2',
                                esc_html__( 'Testimony', 'finance' ) => 'testimony',
                                esc_html__( 'Team', 'finance' ) => 'team',
                                esc_html__( 'Brand', 'finance' ) => 'brand',
                                esc_html__( 'Whitepage', 'finance' ) => 'whitepage',
                                esc_html__( 'Choose Us', 'finance' ) => 'choose_us',
                                esc_html__( 'Choose Us 2', 'finance' ) => 'choose_us_2',
                                esc_html__( 'Choose Us Home Alt', 'finance' ) => 'choose_us_home_alt',
                                esc_html__( 'Slider Version 2', 'finance' ) => 'slider_version_2',
                                esc_html__( 'Whitepage Version 2 ', 'finance' ) => 'whitepage_version_2',
                                esc_html__( 'Choose Us Version 2', 'finance' ) => 'choose_us_version_2',
                                esc_html__( 'Testimony Version 2', 'finance' ) => 'testimony_version_2',
                                esc_html__( 'Step Page Version 2', 'finance' ) => 'step_page_version_2',
                                esc_html__( 'Brand Version 2', 'finance' ) => 'brand_version_2',
                                esc_html__( 'Experience About 2', 'finance' ) => 'experience_about_2',
                                esc_html__( 'Team About 2', 'finance' ) => 'team_about_2',
                                esc_html__( 'Concept About Video', 'finance' ) => 'concept_about_video',
                                esc_html__( 'Concept About 4', 'finance' ) => 'concept_about_4',
                                esc_html__( 'Team About 4', 'finance' ) => 'team_about_4',
                                esc_html__( 'Service Alt', 'finance' ) => 'service_alt',





                                
                             ),
                             'description' => esc_html__( 'Select type row', 'finance' )
      )); 



vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section Title', 'finance'),
                              "param_name" => "ses_title",
                              "value" => "",
                              "description" => esc_html__("Title of Section, Leave a blank do not show frontend.", "finance"),   
    ));
vc_add_param('vc_row',array(
                              "type" => "textarea",
                              "heading" => esc_html__('Section Boldtitle', 'finance'),
                              "param_name" => "ses_boldtitle",
                              "value" => "",
                              "description" => esc_html__("Section Bold Title, Leave a blank do not show frontend.", "finance"),   
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section Title 1', 'finance'),
                              "param_name" => "ses_title1",
                              "value" => "",
                              "description" => esc_html__("Title of Section, Leave a blank do not show frontend.", "finance"),   
    ));

vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section Title 2', 'finance'),
                              "param_name" => "ses_title2",
                              "value" => "",
                              "description" => esc_html__("Title of Section, Leave a blank do not show frontend.", "finance"),   
    ));


vc_add_param('vc_row',array(
                              "type" => "textarea",
                              "heading" => esc_html__('Section Subtitle', 'finance'),
                              "param_name" => "ses_subtitle",
                              "value" => "",
                              "description" => esc_html__("Section Subtitle, Leave a blank do not show frontend.", "finance"),   
    ));
vc_add_param('vc_row',array(
                              "type" => "textarea",
                              "heading" => esc_html__('Section Desc', 'finance'),
                              "param_name" => "ses_desc",
                              "value" => "",
                              "description" => esc_html__("Section Desc, Leave a blank do not show frontend.", "finance"),   
    ));
vc_add_param('vc_row',array(
                             'type' => 'attach_image',
                             'heading' => esc_html__( 'Image Background', 'finance' ),
                             'param_name' => 'ses_image',
                             'value' => '',
                             'description' => esc_html__( 'Select image from media library to do your signature.', 'finance' )
      ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section text btn1', 'finance'),
                              "param_name" => "ses_btn1",
                              "value" => "",
                              "description" => esc_html__("text btn of Section, Leave a blank do not show frontend.", "finance"),   
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section Link btn1', 'finance'),
                              "param_name" => "ses_link1",
                              "value" => "",
                              "description" => esc_html__("Link btn of Section, Leave a blank do not show frontend.", "finance"),  
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section text btn2', 'finance'),
                              "param_name" => "ses_btn2",
                              "value" => "",
                              "description" => esc_html__("text btn of Section, Leave a blank do not show frontend.", "finance"),   
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section Link btn2', 'finance'),
                              "param_name" => "ses_link2",
                              "value" => "",
                              "description" => esc_html__("Link btn of Section, Leave a blank do not show frontend.", "finance"),  
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Tab 1 title', 'finance'),
                              "param_name" => "tab1",
                              "value" => "",
                              "description" => esc_html__("Tab 1 title", "finance"),  
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Tab 2 title', 'finance'),
                              "param_name" => "tab2",
                              "value" => "",
                              "description" => esc_html__("Tab 2 title", "finance"),  
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Tab 3 title', 'finance'),
                              "param_name" => "tab3",
                              "value" => "",
                              "description" => esc_html__("Tab 3 title", "finance"),  
    ));
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Tab 4 title', 'finance'),
                              "param_name" => "tab4",
                              "value" => "",
                              "description" => esc_html__("Tab 4 title", "finance"),  
    ));


// Add new Param in Column  
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Column Title', 'finance'),
                              "param_name" => "title",
                              "value" => "",
                              "description" => esc_html__("Title of column", "finance"),      
                            ) 
    );
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Column Subtitle', 'finance'),
                              "param_name" => "subtitle",
                              "value" => "",
                              "description" => esc_html__("Subtitle of column", "finance"),      
                            ) 
    );
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Link', 'finance'),
                              "param_name" => "link",
                              "value" => "",
                              "description" => esc_html__("Link", "finance"),      
                            ) 
    );
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Button', 'finance'),
                              "param_name" => "button",
                              "value" => "",
                              "description" => esc_html__("Button", "finance"),      
                            ) 
    );  
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Text', 'finance'),
                              "param_name" => "text",
                              "value" => "",
                              "description" => esc_html__("Text", "finance"),      
                            ) 
    );
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Icon', 'finance'),
                              "param_name" => "icon",
                              "value" => "",
                              "description" => esc_html__("Icon", "finance"),      
                            ) 
    );  
vc_add_param('vc_column',array(
                             'type' => 'dropdown',
                             'heading' => esc_html__( 'Type', 'finance' ),
                             'param_name' => 'type',
                             'value' => array(
                                esc_html__( 'None', 'finance' ) => 'none',
                                esc_html__( 'About US Image 1', 'finance' ) => 'about_us_image_1',
                                esc_html__( 'About US Text 1', 'finance' ) => 'about_us_text_1',
                                esc_html__( 'About US Image 2', 'finance' ) => 'about_us_image_2',
                                esc_html__( 'About US Text 2', 'finance' ) => 'about_us_text_2',
                                esc_html__( 'Testimony Image', 'finance' ) => 'testimony_image',
                                esc_html__( 'Testimony Text', 'finance' ) => 'testimony_text',
                                esc_html__( 'Step Mains Version 2', 'finance' ) => 'step_mains_version_2',
                                esc_html__( 'Step Text Version 2', 'finance' ) => 'step_text_version_2',
                                esc_html__( 'Experience Text About 2', 'finance' ) => 'experience_text_about_2',
                                esc_html__( 'Concept Text About video', 'finance' ) => 'concept_text_about_video',
                                esc_html__( 'Concept Text About 4', 'finance' ) => 'concept_text_about_4',
                                esc_html__( 'Service Alt', 'finance' ) => 'service_alt',
                                esc_html__( 'Service Alt Sidebar', 'finance' ) => 'service_alt_sidebar',







                                             ),
                             'description' => esc_html__( 'Select type section content', 'finance' )
      )); 
vc_add_param('vc_column',array(
                             'type' => 'attach_image',
                             'heading' => esc_html__( 'Image Background', 'finance' ),
                             'param_name' => 'image',
                             'value' => '',
                             'description' => esc_html__( 'Select image from media library to do your signature.', 'finance' )
      )); 
}
function artha_widgets_init()
{
    require_once( dirname( __FILE__ ) . '/inc/widgets/recent-posts.php' );
    require_once( dirname( __FILE__ ) . '/inc/widgets/search.php' );

    register_widget( 'My_Recent_Posts_Widget' );
    register_widget('WP_Widget_Search_Extend');

    register_sidebar( array(
        'name'          => esc_html__( 'Sidebar', 'artha-interactive' ),
        'id'            => 'sidebar-1',
        'description'   => esc_html__( 'Add widgets here.', 'artha-interactive' ),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5>',
        'after_title'   => '</h5> <div class="divider-widget"></div>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Sidebar Project', 'artha-interactive' ),
        'id'            => 'sidebar-2',
        'description'   => esc_html__( 'Add widgets here.', 'artha-interactive' ),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5>',
        'after_title'   => '</h5> <div class="divider-widget"></div>',
    ) );
}

add_action( 'widgets_init', 'artha_widgets_init' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function artha_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'artha_content_width', 640 );
}
add_action( 'after_setup_theme', 'artha_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
function artha_scripts() {
	global $artha_options;

    if ( is_page_template( 'page-intro.php' ) ) {
        return false;
    }

	wp_enqueue_style( 'artha-theme-style', get_stylesheet_uri() );

    wp_enqueue_style( 'boostrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
    wp_enqueue_style( 'themify', get_template_directory_uri() . '/assets/css/themify-icons.css' );
    wp_enqueue_style('google-font-poppins', 'https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700');
    wp_enqueue_style('google-font-lato', 'https://fonts.googleapis.com/css?family=Lato:300,400|Poppins:300,400,500,600,700');
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/font-awesome/css/font-awesome.css' );
    wp_enqueue_style( 'rev-fullscreen', get_template_directory_uri() . '/assets/css/fullscreen.css' );
    wp_enqueue_style( 'rev-slider', get_template_directory_uri() . '/assets/rs-plugin/css/settings.css' );
    wp_enqueue_style( 'rev-custom', get_template_directory_uri() . '/assets/css/rev-settings.css' );
    wp_enqueue_style( 'rev-intro', get_template_directory_uri() . '/assets/css/rev-settings-intro.css', ['google-font-poppins']);
    wp_enqueue_style( 'animated', get_template_directory_uri() . '/assets/css/animated-on3step.css' );
    wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.css' );
    wp_enqueue_style( 'owl-theme', get_template_directory_uri() . '/assets/css/owl.theme.css' );
    wp_enqueue_style( 'owl-transition', get_template_directory_uri() . '/assets/css/owl.transitions.css' );
    wp_enqueue_style( 'one3tep', get_template_directory_uri() . '/assets/css/on3step-style.css',  ['google-font-poppins'] );
    wp_enqueue_style( 'one3step-queries', get_template_directory_uri() . '/assets/css/queries-on3step.css' );
    
    wp_enqueue_style( 'artha-style', get_stylesheet_uri() , ['one3step-queries']);


    wp_enqueue_script( 'pluginson3step',  get_template_directory_uri() . '/assets/plugin/pluginson3step.js', false, false, true);
    wp_enqueue_script( 'sticky',  get_template_directory_uri() . '/assets/plugin/sticky.js', false, false, true);
    wp_enqueue_script( 'rev-tools',  get_template_directory_uri() . '/assets/rs-plugin/js/jquery.themepunch.tools.min.js', false, false, true);
    wp_enqueue_script( 'rev',  get_template_directory_uri() . '/assets/rs-plugin/js/jquery.themepunch.revolution.min.js', false, false, true);
    wp_enqueue_script( 'on3step',  get_template_directory_uri() . '/assets/js/on3step.js', false, false, true);
    wp_enqueue_script( 'one3tep-plugin',  get_template_directory_uri() . '/assets/js/plugin-set.js', false, false, true);
    wp_enqueue_script( 'one3tep-nav',  get_template_directory_uri() . '/assets/js/nav.js', false, false, true);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

    if (is_page('contact')) {
        $gmapKey = $artha_options['gmapKey'];
        wp_enqueue_script('gmap', 'https://maps.googleapis.com/maps/api/js?key=' . $gmapKey, false, false, false);
        wp_enqueue_script('contact-map', get_template_directory_uri() . '/assets/js/map-1.js', ['gmap'], false, true);
    }
}
add_action( 'wp_enqueue_scripts', 'artha_scripts' );

function intro_scripts() {
    if ( is_page_template( 'page-intro.php' ) ) {
        wp_enqueue_style( 'boostrap', get_template_directory_uri() . '/assets/intro/css/bootstrap.min.css' );
        
        wp_enqueue_style( 'settings', get_template_directory_uri() . '/assets/intro/rs-plugin/css/settings.css' );
        wp_enqueue_style( 'intro-style', get_template_directory_uri() . '/assets/intro/css/rev-settings.css' );
        wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/intro/font-awesome/css/font-awesome.css' );
        wp_enqueue_style( 'intro-style', get_template_directory_uri() . '/assets/intro/css/intro-style.css' );
        

        wp_enqueue_script( 'pluginintro-3', get_template_directory_uri() . '/assets/intro/plugin/pluginintro.js', array( 'jquery' ), '', true );
        wp_enqueue_script( 'slider-12', get_template_directory_uri() . '/assets/intro/rs-plugin/js/jquery.themepunch.tools.min.js', array('jquery'), '', true);
        wp_enqueue_script( 'slider-23', get_template_directory_uri() . '/assets/intro/rs-plugin/js/jquery.themepunch.revolution.min.js', array('jquery'), '', true);
        wp_enqueue_script( 'intro-js3', get_template_directory_uri() . '/assets/intro/mainintro/intro.js', array('jquery'), '', true);
    }
}
add_action( 'wp_enqueue_scripts', 'intro_scripts', 10 );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

add_filter( 'wp_nav_menu_objects', 'add_has_children_to_nav_items' );

function add_has_children_to_nav_items( $items )
{
    $parents = wp_list_pluck( $items, 'menu_item_parent');

    foreach ( $items as $item ) {
        if (in_array( $item->ID, $parents )) {
            $item->classes[] = 'has-children';
        }
    }


    return $items;
}

/**
 * Numbered pagination on blog page
 * 
 * @return String HTML
 */
function artha_pagination( $query = false ) {
    global $wp_query;

    if ( false !== $query ) {
        $wp_query = $query;
    }
 
    /** Stop execution if there's only 1 page */
    if( $wp_query->max_num_pages <= 1 )
        return;
 
    $paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
    $max   = intval( $wp_query->max_num_pages );
 
    /** Add current page to the array */
    if ( $paged >= 1 )
        $links[] = $paged;
 
    /** Add the pages around the current page to the array */
    if ( $paged >= 3 ) {
        $links[] = $paged - 1;
        $links[] = $paged - 2;
    }
 
    if ( ( $paged + 2 ) <= $max ) {
        $links[] = $paged + 2;
        $links[] = $paged + 1;
    }
 
    echo '<div class="artha-navigation"><ul class="pagination">' . "\n";
 
    /** Previous Post Link */
    if ( get_previous_posts_link() )
        printf( '<li>%s</li>' . "\n", get_previous_posts_link( '&laquo;' ) );
 
    /** Link to first page, plus ellipses if necessary */
    if ( ! in_array( 1, $links ) ) {
        $class = 1 == $paged ? ' class="active"' : '';
 
        printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );
 
        if ( ! in_array( 2, $links ) )
            echo '<li>…</li>';
    }
 
    /** Link to current page, plus 2 pages in either direction if necessary */
    sort( $links );
    foreach ( (array) $links as $link ) {
        $class = $paged == $link ? ' class="active"' : '';
        printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
    }
 
    /** Link to last page, plus ellipses if necessary */
    if ( ! in_array( $max, $links ) ) {
        if ( ! in_array( $max - 1, $links ) )
            echo '<li>…</li>' . "\n";
 
        $class = $paged == $max ? ' class="active"' : '';
        printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
    }
 
    /** Next Post Link */
    if ( get_next_posts_link() )
        printf( '<li>%s</li>' . "\n", get_next_posts_link( '&raquo;' ) );
 
    echo '</ul></div>' . "\n";
 
}

function custom_active_item_classes($classes = array(), $menu_item = false) {            
    global $post;

    if ( is_null( $post ) ) {
        return $classes;
    }

    $classes[] = ($menu_item->url == get_post_type_archive_link($post->post_type)) ? 'current-menu-item active' : '';

    return $classes;
}
add_filter( 'nav_menu_css_class', 'custom_active_item_classes', 10, 2 );

/**
 * Excerpt more filter
 * 
 * @return String
 */
function artha_excerpt_more( $more ) {
    return '...';
}
add_filter( 'excerpt_more', 'artha_excerpt_more', 10, 1 );

/**
 * Breadcrumb
 * 
 * @return String HTML
 */
function artha_breadcrumb() {
    echo '<ul id="crumbs">';
    if (!is_home()) {
        echo '<li><a href="';
        echo esc_url( home_url( '/' ) );
        echo '">';
        echo esc_html__( 'Home', 'artha-interactive' );
        echo "</a></li>";
        if (is_category() || is_single()) {
            echo '<li>';
            the_category(' </li><li> ');
            if (is_single()) {
                echo "</li><li>";
                the_title();
                echo '</li>';
            }
        } elseif (is_page()) {
            echo '<li>';
            echo the_title();
            echo '</li>';
        }
    }
    elseif (is_tag()) {single_tag_title();}
    elseif (is_day()) {echo"<li>" . esc_html__( 'Archive for', 'artha-interactive' ) . " "; the_time('F jS, Y'); echo'</li>';}
    elseif (is_month()) {echo"<li>" . esc_html__( 'Archive for', 'artha-interactive' ) . " "; the_time('F, Y'); echo'</li>';}
    elseif (is_year()) {echo"<li>" . esc_html__( 'Archive for', 'artha-interactive' ) . " "; the_time('Y'); echo'</li>';}
    elseif (is_author()) {echo"<li>" . esc_html__( 'Author Archive', 'artha-interactive' ) . ""; echo'</li>';}
    elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {echo "<li>" . esc_html__( 'Blog Archives', 'artha-interactive' ); echo'</li>';}
    elseif (is_search()) {echo"<li>" . esc_html__( 'Search Results', 'artha-interactive' ); echo'</li>';}
    echo '</ul>';
}






function artha_import_files() {
    return array(
        
        array(
            'import_file_name'           => 'Demo Import Artha',
            'import_file_url'            => 'http://shtheme.com/import/artha/content.xml',
            'import_notice'              => esc_html__( 'Import data example Artha', 'artha' ),
        ),
    );
}
add_filter( 'pt-ocdi/import_files', 'artha_import_files' );




function artha_after_import_setup() {
    // Assign menus to their locations.
    $main_menu = get_term_by( 'name', 'Menu 1', 'primary' );
    

    set_theme_mod( 'nav_menu_locations', array(
            'primary' => $main_menu->term_id,
            
        )
    );

    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title( 'Home' );

    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );

}
add_action( 'pt-ocdi/after_import', 'artha_after_import_setup' );





function artha_custom_style() {
    global $artha_options;

    if ( isset( $artha_options['color_scheme'] ) && ! empty( $artha_options['color_scheme'] ) ) {
        ?>
        <style type="text/css" id="artha-custom-style">
            a:hover,a:active{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.color{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.btn-content{border:3px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.btn-content:hover{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.mainpreloader span{border-top:3px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.social-icons-subnav span:hover{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.white nav .current_page_item > a{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.white nav a.actived{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>!important}.white nav ul ul li a:hover{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.white nav ul ul li a.active{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}#subheader .sub-menu a{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}ul#crumbs li a{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.count-about span.detail{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.features:hover a{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.features span{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.features a{border:3px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.box-icon .icon-choose{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}#testimony blockquote{border:1px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}#testimony h3{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.team .devider-recent-2{border-top:2px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.services blockquote,.grid-item blockquote{border-left:5px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.btn-download{border:3px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.btn-download:hover{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}#filter-porto li.filt-projects:hover,#filter-porto li.filt-projects-w:hover{border:1px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.detaillist{border:1px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.detaillist span{border-bottom:1px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.blog-simple blockquote{border-left:5px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}ul.pagination li a:hover{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.artha-navigation .pagination li.active a,.artha-navigation .pagination li a:hover,.artha-navigation .pagination li a:focus{background-color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>;border-color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.widget .tagcloud a:hover{border:1px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.divider-widget{border-bottom:2px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.input-group-btn button span.icon{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.input-group-btn button:hover span.icon{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.comment-info .c-reply a:hover{border:2px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.comment-info .c-reply a::before{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}#commentform button.btn,#commentform input[type="submit"]{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}a.btn-blog{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.btn-contact{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}#totop{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}form.post-password-form input[type="password"]{border:1px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>!important}.widget_search .search-submit{background:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.widget_rss span.rss-date{color:<?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.white nav a:hover, .white nav .current_page_item > a {color: <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.gal-home .hovereffect .overlay {border-color: <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.gal-home .hovereffect .overlay .devider,.gal-home .hovereffect:hover .overlay .devider{border-top-color: <?php echo esc_attr( $artha_options['color_scheme'] ); ?>}.btn-slider{border: 3px solid <?php echo esc_attr( $artha_options['color_scheme'] ); ?>;}.btn-slider:hover {background: <?php echo esc_attr( $artha_options['color_scheme'] ); ?>;}
        </style>
        <?php
    }
}
add_action( 'wp_head', 'artha_custom_style', 10 );