<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Redux Theme
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function redux_theme_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'redux_theme_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function redux_theme_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'redux_theme_pingback_header' );

function artha_comments( $comment, $args, $depth ) {
    global $post;
    $author_id = $post->post_author;
    $GLOBALS['comment'] = $comment;
    switch ( $comment->comment_type ) :
        case 'pingback' :
        case 'trackback' :
        // Display trackbacks differently than normal comments. ?>
    <ul id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
        <div class="pingback-entry">
            <span class="pingback-heading"><?php esc_html_e( 'Pingback:', 'artha-interactive' ); ?></span> <?php comment_author_link(); ?>
        </div>
    </ul>    
    <?php
        break;
        default :
    // Proceed with normal comments. ?>
    <ul id="ul-comment-<?php comment_ID(); ?>">
        <li id="comment-<?php comment_ID(); ?>">
            <div class="avatar">
                <?php //echo get_avatar( $comment, 45 ); ?>
                <?php echo get_avatar( $comment, $args['avatar_size'] ); ?>
            </div><!-- .comment-author -->
            <div class="comment-info">
                <span class="c-name">
                    <?php comment_author_link(); ?>
                </span>
                <span class="c-date">
                    <?php printf( '%s ' . esc_html__( 'at', 'artha-interactive' ) . ' %s', get_comment_date(), get_comment_time() ); ?>
                </span>
                <span class="c-reply">
                    <?php comment_reply_link( array_merge( $args, array(
                        'reply_text' => esc_html__( 'Reply', 'artha-interactive' ),
                        'depth'      => $depth,
                        'max_depth'  => $args['max_depth'] )
                    ) ); ?>
                </span>
                <?php if ( '0' == $comment->comment_approved ) : ?>
                    <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'artha-interactive' ); ?></p>
                <?php endif; ?>
                </div>
                <div class="comment-content entry clr comment">
                    <?php comment_text(); ?>
                </div><!-- .comment-content -->
                
            <!-- .comment-details -->
        </li><!-- #comment-## -->
    </ul>
    <?php
        break;
    endswitch; // End comment_type check.
}