<?php 
/**
 * Extend Artha Recent Posts Widget 
 *
 * Adds different formatting to the default WordPress Artha Recent Posts Widget
 */
Class My_Recent_Posts_Widget extends WP_Widget {

    /**
     * Sets up a new Artha Recent Posts widget instance.
     *
     * @since 2.8.0
     */
    public function __construct() {
        $widget_ops = array(
            'classname' => 'widget_recent_entries',
            'description' => esc_html__( 'Your site&#8217;s most recent Posts.', 'artha-interactive' ),
            'customize_selective_refresh' => true,
        );
        parent::__construct( 'recent-posts', esc_html__( 'Artha Recent Posts', 'artha-interactive' ), $widget_ops );
        $this->alt_option_name = 'widget_recent_entries';
    }

    function widget($args, $instance) {

        if ( ! isset( $args['widget_id'] ) ) {
            $args['widget_id'] = $this->id;
        }

        $args['before_title'] = '<h5>';
        $args['after_title'] = '</h5>';

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Artha Recent Posts', 'artha-interactive' );

        /** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
        if ( ! $number )
            $number = 5;
        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

        /**
         * Filter the arguments for the Artha Recent Posts widget.
         *
         * @since 3.4.0
         *
         * @see WP_Query::get_posts()
         *
         * @param array $args An array of arguments used to retrieve the recent posts.
         */
        $r = new WP_Query( apply_filters( 'widget_posts_args', array(
            'posts_per_page'      => $number,
            'no_found_rows'       => true,
            'post_status'         => 'publish',
            'ignore_sticky_posts' => true
        ) ) );

        if ($r->have_posts()) :
        ?>
        <?php echo wp_specialchars_decode( $args['before_widget'] ); ?>

        <?php if ( $title ) {
            echo wp_specialchars_decode( $args['before_title'] ) . esc_html( $title ) . wp_specialchars_decode( $args['after_title'] );
        } ?>
        <div class="divider-widget"></div>
        <div class="recent">
        
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>
    <?php $image_sidebar = get_post_meta(get_the_ID(),'_cmb_image_sidebar', true); ?>
    <?php $excerpt_sidebar = get_post_meta(get_the_ID(),'_cmb_excerpt_sidebar', true); ?>
            <div>
        			<img alt="#" class="pull-left" src="<?php echo esc_url($image_sidebar);?>">
                <h6>
                	<a class="link" href="<?php the_permalink(); ?>"><?php echo esc_html( get_the_title() ); ?></a>
                </h6>
            	<p><?php echo esc_attr($excerpt_sidebar);?></p>
            </div>
        <?php endwhile; ?>
        </div>
        <?php echo wp_specialchars_decode( $args['after_widget'] ); ?>
        <?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;
    }

    /**
     * Handles updating the settings for the current Artha Recent Posts widget instance.
     *
     * @since 2.8.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field( $new_instance['title'] );
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
        return $instance;
    }

    /**
     * Outputs the settings form for the Artha Recent Posts widget.
     *
     * @since 2.8.0
     *
     * @param array $instance Current settings.
     */
    public function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'artha-interactive' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>

        <p><label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_attr_e( 'Number of posts to show:', 'artha-interactive' ); ?></label>
        <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" value="<?php echo esc_attr( $number ); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>" />
        <label for="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"><?php esc_attr_e( 'Display post date?', 'artha-interactive' ); ?></label></p>
<?php
    }
}